%global pypi_name markdown-it-py

Name:           python-%{pypi_name}
Version:        3.0.0
Release:        2%{?dist}
Summary:        Python port of markdown-it

# SPDX
License:        MIT
URL:            https://github.com/executablebooks/markdown-it-py
Source0:        %{url}/archive/v%{version}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

# The plugins extras creates a bootstrap loop
%bcond plugins 1

# python-pytest-regressions requires the whole world to build -
# during bootstrapping process of a new Python it's better to skip it
%bcond regression_tests 1

%global _description %{expand:
Markdown parser done right. Its features:
Follows the CommonMark spec for baseline parsing.
Has configurable syntax: you can add new rules and even replace existing ones.
Pluggable: Adds syntax extensions to extend the parser.
High speed & safe by default
}

%description %_description

%package -n     python3-%{pypi_name}
Summary:        %{summary}

%description -n python3-%{pypi_name} %_description

%pyproject_extras_subpkg -n python3-%{pypi_name} linkify %{?with_plugins:plugins}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Remove unnecessary shebang
sed -i '1{\@^#!/usr/bin/env python@d}' markdown_it/cli/parse.py
# Remove coverage (it resides in testing extra which we want to use)
# Upstream issue to move those to another extra:
# https://github.com/executablebooks/markdown-it-py/issues/195
sed -i '/"coverage",/d' pyproject.toml
sed -i '/"pytest-cov",/d' pyproject.toml

%if %{without regression_tests}
sed -i '/"pytest-regressions",/d' pyproject.toml
%endif

%generate_buildrequires
%pyproject_buildrequires -x testing,linkify%{?with_plugins:,plugins}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files markdown_it

%check
pytest_k="not test_pretty and not test_table_tokens and not test_file and not \
test_use_existing_env and not test_store_labels and not test_inline_definitions"
%pytest tests/ %{!?with_regression_tests:-k "$(echo $pytest_k)"}

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE LICENSE.markdown-it
%doc README.md
%{_bindir}/markdown-it


%changelog
* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jul 07 2023 Karolina Surma <ksurma@redhat.com> - 3.0.0-1
- Update to 3.0.0
Resolves: rhbz#2212028

* Thu Jun 29 2023 Python Maint <python-maint@redhat.com> - 2.2.0-3
- Rebuilt for Python 3.12

* Thu Jun 29 2023 Python Maint <python-maint@redhat.com> - 2.2.0-2
- Bootstrap for Python 3.12

* Wed Mar 15 2023 Karolina Surma <ksurma@redhat.com> - 2.2.0-1
- Update to 2.2.0, includes the fix for CVE-2023-26302
Resolves: rhbz#2172373 rhbz#2177154
- Provide extra subpackages: linkify and plugins

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jun 15 2022 Python Maint <python-maint@redhat.com> - 2.1.0-2
- Rebuilt for Python 3.11

* Tue Apr 19 2022 Lumír Balhar <lbalhar@redhat.com> - 2.1.0-1
- Update to 2.1.0
Resolves: rhbz#2075950

* Mon Jan 31 2022 Karolina Surma <ksurma@redhat.com> - 2.0.1-1
- Update to 2.0.1
Resolves: rhbz#2028769
- Generate test dependencies from upstream data instead of hardcoding them

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Aug 04 2021 Karolina Surma <ksurma@redhat.com> - 1.1.0-4
- Enable more tests in %%check using pytest-regressions

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.1.0-2
- Rebuilt for Python 3.10

* Thu May 13 2021 Karolina Surma <ksurma@redhat.com> - 1.1.0-1
- Initial package.
